package PiTube::Controller::Nginx;
use Mojo::Base 'Mojolicious::Controller';
use Mojo::UserAgent;
use Mojo::IOLoop;

use constant HLS => qr/^\/hls\/([a-z0-9\-]+)(_\w+)?(\/\w+)?\.(m3u8|ts)$/i;

sub callback_rtmp {
    my $c = shift;

    if ( $c->param('call') =~ /publish/ ) {
        my $name = $c->param('name');

        # stream
        my $stream = $c->schema->resultset('Stream')->find({
            key => $name,
        });
        $c->render( status => 404, text => '' ), return if ! $stream;

        # kontrola tokenu
        my $user = $c->schema->resultset('User')->find({
            token => $c->param('token')
        });
        $c->render( status => 403, text => ''), return if ! $user;

#        my $acl = $c->schema->resultset('ACL')->user_acl(
#            $user->username,
#        );

        # TODO: autorizace user/stream

        # aktualizace stavu streamu
        $stream->update({
            publish_last     => '\now()',
            publish_user_id  => $user->id,
            publish_time     => ( $c->param('time') // 0 ),
        });

        # zapnuti nahravani
        if ( $c->param('record') && $c->param('record') =~ /(all|audio)/) {
            my $record = $1;
            my $ua = Mojo::UserAgent->new;

            Mojo::IOLoop->timer(1 => sub ($loop) {
                my $res = $ua->get(
                    $c->config->{nginx}{base_url}
                    . "/control/record/start?app=stream&name=$name&rec=$record"
                );
            });
        }

    }

    $c->render( status => 204, text => '' );

}

sub callback_hls {
    my $c = shift;

    $c->app->log->debug($c->req->headers->header('X-Original-URI'));

    if ($c->req->headers->header('X-Original-URI') =~ HLS ) {
        if ( $c->session->{user}{acl}{ $1 } & 4 ) { #TODO: constant
            $c->render( status => 204, text => '' );
            return;
        }
    }

    $c->render( status => 403, text => '');

}

1;
